@@ -14,9 +14,7 @@ class DetaModel(BaseModel):
 
     def __init_subclass__(cls, db_name: Optional[str] = None, **kwargs):
         super(DetaModel, cls).__init_subclass__(**kwargs)
-
-        if cls.__base_name__ is None or not len(cls.__base_name__):
-            cls.__base_name__ = getattr(cls, '__base_name__') or db_name
+        cls.__base_name__ = db_name or cls.__base_name__
 
 
     @classmethod
